# Is image.GetOffsetTable()\[0\] always equal to 1?

**URL:** <https://discourse.itk.org/t/is-image-getoffsettable-0-always-equal-to-1/893>\
**Category:** Engineering\
**Created:** [May 2, 2018, 12:40pm UTC](https://discourse.itk.org/t/is-image-getoffsettable-0-always-equal-to-1/893 "2018-05-02T12:40:48Z")\
**Posts on this page:** 1\
**Showing post:** 5

<div class="post-metadata">

**Author:** ![Niels\_Dekker](https://discourse.itk.org/letter_avatar_proxy/v4/letter/n/9d8465/32.png) [@Niels\_Dekker](https://discourse.itk.org/u/Niels_Dekker)\
**Post date:** [May 2, 2018, 1:47pm UTC](https://discourse.itk.org/t/is-image-getoffsettable-0-always-equal-to-1/893/5 "2018-05-02T13:47:47Z")

</div>

> [@blowekamp](#):
>
> Did you quantify the performance difference? Do you have timing results from the experiment?

With my test from [Removal of `virtual` keywords from ConstNeighborhoodIterator - #4 by blowekamp](https://discourse.itk.org/t/removal-of-virtual-keywords-from-constneighborhooditerator/814/4) (topic item 4) I observed a very small increase of the run-time duration, when adding support for `offsetTable[0] != 1`, from ~12 to ~13 seconds. (Compiled by MSVC2015 x64 Release.) The performance drop certainly remains well below 10%. 🙂

---

_[View the full topic](https://discourse.itk.org/t/is-image-getoffsettable-0-always-equal-to-1/893)._
